| metadata_series | R Documentation |
Metadata for all economic series included in the package.
metadata_series
A tibble with metadata:
Short series identifier
Full series description
Data frequency (D = daily, M = monthly, Q = quarterly)
Data source
Name of the date column in the dataset
Name of the main value column(s) in the dataset
Grouping column(s) for long-format datasets, or NA
First observation date
Last observation date
Various. BCB-SGS metadata and source institutions are documented on the individual dataset pages; see the BCB SGS series search.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.